@@ -17,7 +17,7 @@ BinarizeCounts.default <- function(
   verbose = TRUE,
   ...
 ) {
-  if (inherits(x = object, what = "dgCMatrix")) {
+  if (inherits(x = object, what = "CsparseMatrix")) {
     slot(object = object, name = "x") <- rep.int(
       x = 1,
       times = length(
@@ -152,7 +152,7 @@ CreateMotifMatrix <- function(
       motif.matrix <- motifmatchr::motifCounts(object = motif_ix)
     } else {
       motif.matrix <- motifmatchr::motifMatches(object = motif_ix)
-      motif.matrix <- as(Class = "dgCMatrix", object = motif.matrix)
+      motif.matrix <- as(Class = "CsparseMatrix", object = motif.matrix)
     }
   }
   rownames(motif.matrix) <- GRangesToString(grange = features, sep = sep)
@@ -462,13 +462,31 @@ RegionStats.default <- function(
     stop("Please install Biostrings: BiocManager::install('Biostrings')")
   }
   sequence.length <- width(x = object)
+  common.seq <- intersect(x = seqlevels(x = object), y = seqlevels(x = genome))
+  if (length(x = common.seq) < length(x = seqlevels(x = object))) {
+    warning("Not all seqlevels present in supplied genome", immediate. = TRUE)
+  }
+  seq.keep <- as.character(x = seqnames(x = object)) %in% common.seq
+  enum <- seq_along(along.with = seq.keep)
+  object <- object[seq.keep]
+  object <- keepSeqlevels(x = object, value = common.seq, pruning.mode = "coarse")
   sequences <- Biostrings::getSeq(x = genome, object)
   gc <- Biostrings::letterFrequency(
     x = sequences, letters = 'CG'
-  ) / sequence.length * 100
+  ) / sequence.length[seq.keep] * 100
   colnames(gc) <- 'GC.percent'
   dinuc <- Biostrings::dinucleotideFrequency(sequences)
-  sequence.stats <- cbind(dinuc, gc, sequence.length)
+  sequence.stats <- cbind(dinuc, gc)
+  # fill missing seqnames with NA
+  nadf <- as.data.frame(
+    x = matrix(nrow = sum(!seq.keep), ncol = ncol(x = sequence.stats))
+  )
+  colnames(x = nadf) <- colnames(x = sequence.stats)
+  rownames(x = nadf) <- enum[!seq.keep]
+  rownames(x = sequence.stats) <- enum[seq.keep]
+  sequence.stats <- rbind(sequence.stats, nadf)
+  sequence.stats <- sequence.stats[enum, ]
+  sequence.stats <- cbind(sequence.stats, sequence.length)
   return(sequence.stats)
 }
 
@@ -577,8 +595,8 @@ RunTFIDF.default <- function(
   if (inherits(x = object, what = "data.frame")) {
     object <- as.matrix(x = object)
   }
-  if (!inherits(x = object, what = "dgCMatrix")) {
-    object <- as(object = object, Class = "dgCMatrix")
+  if (!inherits(x = object, what = "CsparseMatrix")) {
+    object <- as(object = object, Class = "CsparseMatrix")
   }
   if (verbose) {
     message("Performing TF-IDF normalization")
@@ -667,7 +685,7 @@ RunTFIDF.Assay <- function(
     verbose = verbose,
     ...
   )
-  new.data <- as(object = new.data, Class = "dgCMatrix")
+  new.data <- as(object = new.data, Class = "CsparseMatrix")
   object <- SetAssayData(
     object = object,
     slot = "data",
